@@ -720,12 +720,18 @@ create_pak_repo <- local({
     "win.binary/mingw32/x86_64/bin/windows/contrib/4.2" = "../../../../../../../mingw32/x86_64",
     "win.binary/mingw32/x86_64/bin/windows/contrib/4.3" = "../../../../../../../mingw32/x86_64",
     "win.binary/mingw32/x86_64/bin/windows/contrib/4.4" = "../../../../../../../mingw32/x86_64",
+    "win.binary/mingw32/x86_64/bin/windows/contrib/4.5" = "../../../../../../../mingw32/x86_64",
+    "win.binary/mingw32/x86_64/bin/windows/contrib/4.6" = "../../../../../../../mingw32/x86_64",
     "mac.binary.big-sur-arm64/darwin20/aarch64/bin/macosx/big-sur-arm64/contrib/4.1" = "../../../../../../../../darwin20/aarch64",
     "mac.binary.big-sur-arm64/darwin20/aarch64/bin/macosx/big-sur-arm64/contrib/4.2" = "../../../../../../../../darwin20/aarch64",
     "mac.binary.big-sur-arm64/darwin20/aarch64/bin/macosx/big-sur-arm64/contrib/4.3" = "../../../../../../../../darwin20/aarch64",
     "mac.binary.big-sur-arm64/darwin20/aarch64/bin/macosx/big-sur-arm64/contrib/4.4" = "../../../../../../../../darwin20/aarch64",
+    "mac.binary.big-sur-arm64/darwin20/aarch64/bin/macosx/big-sur-arm64/contrib/4.5" = "../../../../../../../../darwin20/aarch64",
+    "mac.binary.big-sur-arm64/darwin20/aarch64/bin/macosx/big-sur-arm64/contrib/4.6" = "../../../../../../../../darwin20/aarch64",
     "mac.binary.big-sur-x86_64/darwin20/x86_64/bin/macosx/big-sur-x86_64/contrib/4.3" = "../../../../../../../../darwin20/x86_64",
     "mac.binary.big-sur-x86_64/darwin20/x86_64/bin/macosx/big-sur-x86_64/contrib/4.4" = "../../../../../../../../darwin20/x86_64",
+    "mac.binary.big-sur-x86_64/darwin20/x86_64/bin/macosx/big-sur-x86_64/contrib/4.5" = "../../../../../../../../darwin20/x86_64",
+    "mac.binary.big-sur-x86_64/darwin20/x86_64/bin/macosx/big-sur-x86_64/contrib/4.6" = "../../../../../../../../darwin20/x86_64",
     "mac.binary/darwin17.0/x86_64/bin/macosx/contrib/4.0" = "../../../../../../../darwin17.0/x86_64",
     "mac.binary/darwin17.0/x86_64/bin/macosx/contrib/4.1" = "../../../../../../../darwin17.0/x86_64",
     "mac.binary/darwin17.0/x86_64/bin/macosx/contrib/4.2" = "../../../../../../../darwin17.0/x86_64",
@@ -745,10 +751,14 @@ create_pak_repo <- local({
     "bin/windows/contrib/4.2" = "../../../../mingw32/x86_64",
     "bin/windows/contrib/4.3" = "../../../../mingw32/x86_64",
     "bin/windows/contrib/4.4" = "../../../../mingw32/x86_64",
+    "bin/windows/contrib/4.5" = "../../../../mingw32/x86_64",
+    "bin/windows/contrib/4.6" = "../../../../mingw32/x86_64",
     "bin/macosx/big-sur-arm64/contrib/4.1" = "../../../../../darwin20/aarch64",
     "bin/macosx/big-sur-arm64/contrib/4.2" = "../../../../../darwin20/aarch64",
     "bin/macosx/big-sur-arm64/contrib/4.3" = "../../../../../darwin20/aarch64",
     "bin/macosx/big-sur-arm64/contrib/4.4" = "../../../../../darwin20/aarch64",
+    "bin/macosx/big-sur-arm64/contrib/4.5" = "../../../../../darwin20/aarch64",
+    "bin/macosx/big-sur-arm64/contrib/4.6" = "../../../../../darwin20/aarch64",
     "bin/macosx/contrib/4.0" = "../../../../darwin17.0/x86_64",
     "bin/macosx/contrib/4.1" = "../../../../darwin17.0/x86_64",
     "bin/macosx/contrib/4.2" = "../../../../darwin17.0/x86_64",
@@ -759,6 +769,8 @@ create_pak_repo <- local({
     "bin/macosx/el-capitan/contrib/3.6" = "../../../../../darwin15.6.0/x86_64",
     "bin/macosx/big-sur-x86_64/contrib/4.3" = "../../../../../darwin20/x86_64",
     "bin/macosx/big-sur-x86_64/contrib/4.4" = "../../../../../darwin20/x86_64",
+    "bin/macosx/big-sur-x86_64/contrib/4.5" = "../../../../../darwin20/x86_64",
+    "bin/macosx/big-sur-x86_64/contrib/4.6" = "../../../../../darwin20/x86_64",
     "src/contrib" = "../../linux/x86_64"
   )
 
